@@ -5,7 +5,7 @@ use warnings;
 use POSIX ':sys_wait_h';
 
 # ABSTRACT: Code for the AnyEvent::Open3::Simple idle implementation
-our $VERSION = '0.87'; # VERSION
+our $VERSION = '0.88'; # VERSION
 
 sub _watcher
 {
@@ -27,7 +27,23 @@ AnyEvent::Open3::Simple::Idle - Code for the AnyEvent::Open3::Simple idle implem
 
 =head1 VERSION
 
-version 0.87
+version 0.88
+
+=head1 SYNOPSIS
+
+ $ perldoc AnyEvent::Open3::Simple
+
+=head1 DESCRIPTION
+
+This is a private module.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<AnyEvent::Open3::Simple>
+
+=back
 
 =head1 AUTHOR
 
@@ -41,7 +57,7 @@ Scott Wiersdorf
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2019 by Graham Ollis.
+This software is copyright (c) 2012-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
